summaryrefslogtreecommitdiffstats
path: root/chrome/browser/login_prompt.cc
diff options
context:
space:
mode:
authorjcampan@chromium.org <jcampan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-19 00:42:30 +0000
committerjcampan@chromium.org <jcampan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-19 00:42:30 +0000
commita3a1d14240d6e41a0b6732ebcd3600399c64b26a (patch)
treea38ced2761bdf4447bf180470fd5dade857ef11b /chrome/browser/login_prompt.cc
parent5b62083c99317965244123c031c707d53f0a03f1 (diff)
downloadchromium_src-a3a1d14240d6e41a0b6732ebcd3600399c64b26a.zip
chromium_src-a3a1d14240d6e41a0b6732ebcd3600399c64b26a.tar.gz
chromium_src-a3a1d14240d6e41a0b6732ebcd3600399c64b26a.tar.bz2
Review URL: http://codereview.chromium.org/14809
git-svn-id: svn://svn.chromium.org/chrome/trunk/src@7281 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/login_prompt.cc')
-rw-r--r--chrome/browser/login_prompt.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/login_prompt.cc b/chrome/browser/login_prompt.cc
index 1e95b0c..db9d775 100644
--- a/chrome/browser/login_prompt.cc
+++ b/chrome/browser/login_prompt.cc
@@ -84,11 +84,11 @@ class LoginHandlerImpl : public LoginHandler,
SendNotifications();
}
- // Returns the TabContents that needs authentication.
- TabContents* GetTabContentsForLogin() {
+ // Returns the WebContents that needs authentication.
+ WebContents* GetWebContentsForLogin() {
DCHECK(MessageLoop::current() == ui_loop_);
- return tab_util::GetTabContentsByID(render_process_host_id_,
+ return tab_util::GetWebContentsByID(render_process_host_id_,
tab_contents_id_);
}
@@ -238,7 +238,7 @@ class LoginHandlerImpl : public LoginHandler,
DCHECK(MessageLoop::current() == ui_loop_);
NotificationService* service = NotificationService::current();
- TabContents* requesting_contents = GetTabContentsForLogin();
+ WebContents* requesting_contents = GetWebContentsForLogin();
if (!requesting_contents)
return;
@@ -311,7 +311,7 @@ class LoginDialogTask : public Task {
}
void Run() {
- TabContents* parent_contents = handler_->GetTabContentsForLogin();
+ WebContents* parent_contents = handler_->GetWebContentsForLogin();
if (!parent_contents) {
// The request was probably cancelled.
return;